@@ -6,10 +6,17 @@
 #include <stdint.h>
 #include <sys/types.h>
 
+int memfd_create_wrapper(const char *name, unsigned mode);
+
 int memfd_new(const char *name);
 #if 0 /// UNNEEDED by elogind
 int memfd_new_and_map(const char *name, size_t sz, void **p);
+int memfd_new_and_seal(const char *name, const void *data, size_t sz);
+#endif // 0
 
+int memfd_add_seals(int fd, unsigned int seals);
+#if 0 /// UNNEEDED by elogind
+int memfd_get_seals(int fd, unsigned int *ret_seals);
 int memfd_map(int fd, uint64_t offset, size_t size, void **p);
 #endif // 0
 
