@@ -16,12 +16,12 @@ int main(int argc, char *argv[]) {
                 .un.sun_path = "/run/systemd/cgroups-agent",
         };
 
-        _cleanup_close_ int fd = -1;
+        _cleanup_close_ int fd = -EBADF;
         ssize_t n;
         size_t l;
         int r;
 
-        r = rearrange_stdio(-1, -1, -1);
+        r = make_null_stdio();
         if (r < 0) {
                 log_error_errno(r, "Failed to connect stdin/stdout/stderr with /dev/null: %m");
                 return EXIT_FAILURE;
