@@ -391,6 +391,7 @@ static int export_legacy_dbus_address(
         return PAM_SUCCESS;
 }
 
+#if 0 /// elogind does not support session limits that require systemd to run the show
 static int append_session_memory_max(pam_handle_t *handle, sd_bus_message *m, const char *limit) {
         uint64_t val;
         int r;
@@ -466,7 +467,6 @@ static int append_session_tasks_max(pam_handle_t *handle, sd_bus_message *m, con
         return PAM_SUCCESS;
 }
 
-#if 0 /// elogind neither handles io_weight nor cpu_weight
 static int append_session_cpu_weight(pam_handle_t *handle, sd_bus_message *m, const char *limit) {
         uint64_t val;
         int r;
@@ -780,13 +780,18 @@ static uint64_t pick_default_capability_ambient_set(
                 const char *seat) {
 
         /* If not configured otherwise, let's enable CAP_WAKE_ALARM for regular users when logging in on a
-         * seat (i.e. when they are present physically on the device), or when invoked for the elogind --user
+         * seat (i.e. when they are present physically on the device), or when invoked for the systemd --user
          * instances. This allows desktops to install CAP_WAKE_ALARM to implement alarm clock apps without
          * much fuss. */
 
         return ur &&
                 user_record_disposition(ur) == USER_REGULAR &&
-                (streq_ptr(service, "elogind-user") || !isempty(seat)) ? (UINT64_C(1) << CAP_WAKE_ALARM) : UINT64_MAX;
+#if 0 /// elogind also recognizes openrc-user
+                (streq_ptr(service, "systemd-user") || !isempty(seat)) ? (UINT64_C(1) << CAP_WAKE_ALARM) : UINT64_MAX;
+#else // 0
+                (streq_ptr(service, "openrc-user") || streq_ptr(service, "systemd-user") || !isempty(seat))
+                        ? (UINT64_C(1) << CAP_WAKE_ALARM) : UINT64_MAX;
+#endif // 0
 }
 
 typedef struct SessionContext {
@@ -803,11 +808,13 @@ typedef struct SessionContext {
         const bool remote;
         const char *remote_user;
         const char *remote_host;
+#if 0 /// elogind does not support session limits that require systemd to run the show
         const char *memory_max;
         const char *tasks_max;
         const char *cpu_weight;
         const char *io_weight;
         const char *runtime_max_sec;
+#endif // 0
 } SessionContext;
 
 static int create_session_message(
@@ -864,6 +871,7 @@ static int create_session_message(
         if (r < 0)
                 return r;
 
+#if 0 /// elogind does not support session limits that require systemd to run the show
         r = append_session_memory_max(handle, m, context->memory_max);
         if (r != PAM_SUCCESS)
                 return r;
@@ -876,7 +884,6 @@ static int create_session_message(
         if (r != PAM_SUCCESS)
                 return r;
 
-#if 0 /// elogind neither handles io_weight nor cpu_weight
         r = append_session_cpu_weight(handle, m, context->cpu_weight);
         if (r != PAM_SUCCESS)
                 return r;
@@ -912,8 +919,13 @@ _public_ PAM_EXTERN int pam_sm_open_session(
                 *remote_user = NULL, *remote_host = NULL,
                 *seat = NULL,
                 *type = NULL, *class = NULL,
+#if 0 /// elogind does not support session limits that require systemd.resource-control
                 *class_pam = NULL, *type_pam = NULL, *cvtnr = NULL, *desktop = NULL, *desktop_pam = NULL,
                 *memory_max = NULL, *tasks_max = NULL, *cpu_weight = NULL, *io_weight = NULL, *runtime_max_sec = NULL;
+#else // 0
+                *class_pam = NULL, *type_pam = NULL, *cvtnr = NULL, *desktop = NULL, *desktop_pam = NULL;
+#endif // 0
+
         uint64_t default_capability_bounding_set = UINT64_MAX, default_capability_ambient_set = UINT64_MAX;
         _cleanup_(sd_bus_flush_close_unrefp) sd_bus *bus = NULL;
         _cleanup_(user_record_unrefp) UserRecord *ur = NULL;
@@ -991,7 +1003,18 @@ _public_ PAM_EXTERN int pam_sm_open_session(
 
         tty = strempty(tty);
 
+#if 0 /// Detect when elogind is called from an openrc-user PAM stack.
         if (strchr(tty, ':')) {
+#else // 0
+        if (streq_ptr(service, "openrc-user")) {
+                /* If we detect that we are running in the "openrc-user" PAM stack, then let's patch the class to
+                 * 'manager' if not set, simply for robustness reasons. */
+                type = "unspecified";
+                class = IN_SET(user_record_disposition(ur), USER_INTRINSIC, USER_SYSTEM, USER_DYNAMIC) ?
+                        "manager-early" : "manager";
+                tty = NULL;
+        } else if (strchr(tty, ':')) {
+#endif // 0
                 /* A tty with a colon is usually an X11 display, placed there to show up in utmp. We rearrange things
                  * and don't pretend that an X display was a tty. */
                 if (isempty(display))
@@ -1047,23 +1070,23 @@ _public_ PAM_EXTERN int pam_sm_open_session(
 
         remote = !isempty(remote_host) && !is_localhost(remote_host);
 
+#if 0 /// elogind does not handle session limits
         r = pam_get_data(handle, "systemd.memory_max", (const void **)&memory_max);
         if (!IN_SET(r, PAM_SUCCESS, PAM_NO_MODULE_DATA))
                 return pam_syslog_pam_error(handle, LOG_ERR, r, "Failed to get PAM systemd.memory_max data: @PAMERR@");
         r = pam_get_data(handle, "systemd.tasks_max",  (const void **)&tasks_max);
         if (!IN_SET(r, PAM_SUCCESS, PAM_NO_MODULE_DATA))
                 return pam_syslog_pam_error(handle, LOG_ERR, r, "Failed to get PAM systemd.tasks_max data: @PAMERR@");
-#if 0 /// elogind neither handles io_weight nor cpu_weight
         r = pam_get_data(handle, "systemd.cpu_weight", (const void **)&cpu_weight);
         if (!IN_SET(r, PAM_SUCCESS, PAM_NO_MODULE_DATA))
                 return pam_syslog_pam_error(handle, LOG_ERR, r, "Failed to get PAM systemd.cpu_weight data: @PAMERR@");
         r = pam_get_data(handle, "systemd.io_weight",  (const void **)&io_weight);
         if (!IN_SET(r, PAM_SUCCESS, PAM_NO_MODULE_DATA))
                 return pam_syslog_pam_error(handle, LOG_ERR, r, "Failed to get PAM systemd.io_weight data: @PAMERR@");
-#endif // 0
         r = pam_get_data(handle, "elogind.runtime_max_sec", (const void **)&runtime_max_sec);
         if (!IN_SET(r, PAM_SUCCESS, PAM_NO_MODULE_DATA))
                 return pam_syslog_pam_error(handle, LOG_ERR, r, "Failed to get PAM elogind.runtime_max_sec data: @PAMERR@");
+#endif // 0
 
         /* Talk to logind over the message bus */
         r = pam_acquire_bus_connection(handle, "pam-elogind", &bus, &d);
@@ -1078,10 +1101,12 @@ _public_ PAM_EXTERN int pam_sm_open_session(
                          type, class, strempty(desktop),
                          strempty(seat), vtnr, strempty(tty), strempty(display),
                          yes_no(remote), strempty(remote_user), strempty(remote_host));
+#if 0 /// elogind does not support session limits, which would need systemd.resource-control
         pam_debug_syslog(handle, debug,
                          "Session limits: "
                          "memory_max=%s tasks_max=%s cpu_weight=%s io_weight=%s runtime_max_sec=%s",
                          strna(memory_max), strna(tasks_max), strna(cpu_weight), strna(io_weight), strna(runtime_max_sec));
+#endif // 0
 
         const SessionContext context = {
                 .uid = ur->uid,
@@ -1097,11 +1122,13 @@ _public_ PAM_EXTERN int pam_sm_open_session(
                 .remote = remote,
                 .remote_user = remote_user,
                 .remote_host = remote_host,
+#if 0 /// elogind does not support session limits that require systemd to run the show
                 .memory_max = memory_max,
                 .tasks_max = tasks_max,
                 .cpu_weight = cpu_weight,
                 .io_weight = io_weight,
                 .runtime_max_sec = runtime_max_sec,
+#endif // 0
         };
 
         r = create_session_message(bus,
