@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: LGPL-2.1+ */
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
 #pragma once
 
 #include "missing_sched.h"
@@ -16,16 +16,12 @@
                           CLONE_NEWUSER|                                \
                           CLONE_NEWUTS))
 
-#define NAMESPACE_FLAGS_INITIAL  ((unsigned long) -1)
+#define NAMESPACE_FLAGS_INITIAL  ULONG_MAX
 
 #if 0 /// UNNEEDED by elogind
 int namespace_flags_from_string(const char *name, unsigned long *ret);
 #endif // 0
 int namespace_flags_to_string(unsigned long flags, char **ret);
-
-struct namespace_flag_map {
-        unsigned long flag;
-        const char *name;
-};
-
-extern const struct namespace_flag_map namespace_flag_map[];
+#if 0 /// UNNEEDED by elogind
+const char *namespace_single_flag_to_string(unsigned long flag);
+#endif // 0
