@@ -10,7 +10,7 @@
 #include <stdbool.h>
 #include <sys/types.h>
 
-#include "label.h"
+#include "label-util.h"
 #include "macro.h"
 
 #define SMACK_FLOOR_LABEL "_"
@@ -30,6 +30,7 @@ typedef enum SmackAttr {
 #endif // 0
 
 bool mac_smack_use(void);
+int mac_smack_init(void);
 
 int mac_smack_fix_full(int atfd, const char *inode_path, const char *label_path, LabelFixFlags flags);
 static inline int mac_smack_fix(const char *path, LabelFixFlags flags) {
@@ -42,10 +43,16 @@ const char* smack_attr_to_string(SmackAttr i) _const_;
 SmackAttr smack_attr_from_string(const char *s) _pure_;
 int mac_smack_read(const char *path, SmackAttr attr, char **label);
 int mac_smack_read_fd(int fd, SmackAttr attr, char **label);
-int mac_smack_apply(const char *path, SmackAttr attr, const char *label);
+int mac_smack_apply_at(int dir_fd, const char *path, SmackAttr attr, const char *label);
+static inline int mac_smack_apply(const char *path, SmackAttr attr, const char *label) {
+        return mac_smack_apply_at(AT_FDCWD, path, attr, label);
+}
 int mac_smack_apply_fd(int fd, SmackAttr attr, const char *label);
 int mac_smack_apply_pid(pid_t pid, const char *label);
 int mac_smack_copy(const char *dest, const char *src);
 
-int rename_and_apply_smack_floor_label(const char *temp_path, const char *dest_path);
+int renameat_and_apply_smack_floor_label(int fdf, const char *from, int fdt, const char *to);
+static inline int rename_and_apply_smack_floor_label(const char *from, const char *to) {
+        return renameat_and_apply_smack_floor_label(AT_FDCWD, from, AT_FDCWD, to);
+}
 #endif // 0
